==> php-residence_0.2.4.tar.gz: php-residence/includes/lang/en/clienti.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "The dates are wrong"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "You must insert the fare type"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "Non  stato ancora inserito il prezzo della":	$messaggio = "You must still insert the price of"; break;
case "per la settimana dal":  			$messaggio = "for the week from"; break;
case "per il giorno dal":  			$messaggio = "for the day from"; break;
case "al":  					$messaggio = "to"; break;
case "La settimana dal":  			$messaggio = "The week from"; break;
case "Il giorno dal":  				$messaggio = "The day from"; break;
case " piena":  				$messaggio = "is full"; break;
case " pieno":  				$messaggio = "is full"; break;
case "Il numero di settimane del costo aggiuntivo settimanale n":	$messaggio = "The number of weeks of the weekly extra cost n"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero n":	$messaggio = "The number of days of the daily extra cost n"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "is bigger than the number of weeks of the reservation"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "is bigger than the number of days of the reservation"; break;
case "Non ci sono appartamenti con le caratteristiche richieste":	$messaggio = "There are no apartments with the requested features"; break;
case "Non c' nessun appartamento tra quelli richiesti che possa ospitare":	$messaggio = "There are no apartments between the requested ones that can accomodate"; break;
case "persone":  				$messaggio = "people"; break;
case "Nel periodo selezionato non  possibile ospitare il cliente in un appartamento tra quelli richiesti":	$messaggio = "In the selected period is not possible to accomodate the client in any of the requested apartments"; break;
case "Si dovr occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "At least one period of the assignation rule 1 will have to be occupied"; break;
case "Si devono fare i seguenti spostamenti nei periodi della regola di assegnazione 1":	$messaggio = "Movements that must be done in the periods of the assignation rule 1"; break;
case "La prenotazione dal":  			$messaggio = "The reservation from"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "verr spostata dall'appartamento":  	$messaggio = "will be moved from apartment"; break;
case "La nuova prenotazione verr inserita nell'appartamento":	$messaggio = "The new reservation will be inserted in the apartment"; break;
case "Non si pu procedere perch la tabella prenotazioni  cambiata nel frattempo":	$messaggio = "Can't continue because the reservations table has changed meanwhile"; break;
case "Se si continua l'assegnazione dell'appartamento non terr conto degli appartamenti richiesti":	$messaggio = "If you continue the apartment assignation will not respect the requested apartments"; break;
case "Continua lo stesso":  			$messaggio = "Continue anyway"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Non esistono clienti chiamati":  		$messaggio = "There are no clients called"; break;
case "nel database":  				$messaggio = "in the database"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Insert a new client's data"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname"; break;
case "nato il":	  				$messaggio = "borned the"; break;
case "CAP":  					$messaggio = "postal code"; break;
case "Telefono":  				$messaggio = "Phone n"; break;
case "2 telefono":  				$messaggio = "2nd phone n"; break;
case "3 telefono":  				$messaggio = "3rd phone n"; break;
case "Utilizza il cliente":  			$messaggio = "Use client"; break;
case "per la prenotazione":  			$messaggio = "for the reservation"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modify the data of client"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "Insert a new client"; break;
case " necessario inserire il cognome del cliente":	$messaggio = "The client's surname is needed"; break;
case "I dati del cliente":  			$messaggio = "The data of client"; break;
case "sono stati inseriti":  			$messaggio = "have been inserted"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Insert or modify a client's data"; break;
case "Cognome":  				$messaggio = "Surname"; break;
case "nome":  					$messaggio = "name"; break;
case "sesso":  					$messaggio = "gender"; break;
case "data di nascita":  			$messaggio = "birthday"; break;
case "anno con 4 cifre":  			$messaggio = "year with 4 digits"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "citt":  					$messaggio = "city"; break;
case "Via":  					$messaggio = "Street"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Vicolo":  				$messaggio = "Road"; break;
case "Numero di telefono":  			$messaggio = "Telephone number"; break;
case "Secondo telefono":  			$messaggio = "Second telephone"; break;
case "Terzo telefono":  			$messaggio = "Third telephone"; break;
case "Numero di fax":  				$messaggio = "Fax number"; break;
case "Seconda persona di riferimento":  	$messaggio = "Second reference person"; break;
case "Inserisci i dati":  			$messaggio = "Insert data"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Italia":  				$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence_0.3.tar.gz: php-residence/includes/lang/en/clienti.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "The dates are wrong"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "You must insert the fare type"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "Non  stato ancora inserito il prezzo della":	$messaggio = "You must still insert the price of"; break;
case "per la settimana dal":  			$messaggio = "for the week from"; break;
case "per il giorno dal":  			$messaggio = "for the day from"; break;
case "al":  					$messaggio = "to"; break;
case "La settimana dal":  			$messaggio = "The week from"; break;
case "Il giorno dal":  				$messaggio = "The day from"; break;
case " piena":  				$messaggio = "is full"; break;
case " pieno":  				$messaggio = "is full"; break;
case "Il numero di settimane del costo aggiuntivo settimanale n":	$messaggio = "The number of weeks of the weekly extra cost n"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero n":	$messaggio = "The number of days of the daily extra cost n"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "is bigger than the number of weeks of the reservation"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "is bigger than the number of days of the reservation"; break;
case "Non ci sono appartamenti con le caratteristiche richieste":	$messaggio = "There are no apartments with the requested features"; break;
case "Non c' nessun appartamento tra quelli richiesti che possa ospitare":	$messaggio = "There are no apartments between the requested ones that can accomodate"; break;
case "persone":  				$messaggio = "people"; break;
case "Nel periodo selezionato non  possibile ospitare il cliente in un appartamento tra quelli richiesti":	$messaggio = "In the selected period is not possible to accomodate the client in any of the requested apartments"; break;
case "Si dovr occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "At least one period of the assignation rule 1 will have to be occupied"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <font color=\"blue\">regola di assegnazione 1</font>":	$messaggio = "Movements that must be done in the periods of the <font color=\"blue\">assignation rule 1</font>"; break;
case "La prenotazione dal":  			$messaggio = "The reservation from"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "verr spostata dall'appartamento":  	$messaggio = "will be moved from apartment"; break;
case "La nuova prenotazione verr inserita nell'appartamento":	$messaggio = "The new reservation will be inserted in the apartment"; break;
case "Non si pu procedere perch la tabella prenotazioni  cambiata nel frattempo":	$messaggio = "Can't continue because the reservations table has changed meanwhile"; break;
case "Se si continua l'assegnazione dell'appartamento non terr conto degli appartamenti richiesti":	$messaggio = "If you continue the apartment assignation will not respect the requested apartments"; break;
case "Continua lo stesso":  			$messaggio = "Continue anyway"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Non esistono clienti chiamati":  		$messaggio = "There are no clients called"; break;
case "nel database":  				$messaggio = "in the database"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Insert a new client's data"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname"; break;
case "nato il":	  				$messaggio = "borned the"; break;
case "CAP":  					$messaggio = "postal code"; break;
case "Telefono":  				$messaggio = "Phone n"; break;
case "2 telefono":  				$messaggio = "2nd phone n"; break;
case "3 telefono":  				$messaggio = "3rd phone n"; break;
case "Utilizza il cliente":  			$messaggio = "Use client"; break;
case "per la prenotazione":  			$messaggio = "for the reservation"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modify the data of client"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "Insert a new client"; break;
case " necessario inserire il cognome del cliente":	$messaggio = "The client's surname is needed"; break;
case "I dati del cliente":  			$messaggio = "The data of client"; break;
case "sono stati inseriti":  			$messaggio = "have been inserted"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Insert or modify a client's data"; break;
case "Cognome":  				$messaggio = "Surname"; break;
case "nome":  					$messaggio = "name"; break;
case "sesso":  					$messaggio = "gender"; break;
case "data di nascita":  			$messaggio = "birthday"; break;
case "anno con 4 cifre":  			$messaggio = "year with 4 digits"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "citt":  					$messaggio = "city"; break;
case "Via":  					$messaggio = "Street"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Vicolo":  				$messaggio = "Road"; break;
case "Numero di telefono":  			$messaggio = "Telephone number"; break;
case "Secondo telefono":  			$messaggio = "Second telephone"; break;
case "Terzo telefono":  			$messaggio = "Third telephone"; break;
case "Numero di fax":  				$messaggio = "Fax number"; break;
case "Seconda persona di riferimento":  	$messaggio = "Second reference person"; break;
case "Inserisci i dati":  			$messaggio = "Insert data"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Italia":  				$messaggio = ""; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "data specific to the 2 reference people will not be changed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
